@@ -19,8 +19,15 @@
 
 #include "IndentHandler.h"
 
+
+#include <QtDebug>
+
 #include "UiGuiSettings.h"
 
+#ifdef Q_OS_WIN32
+#include <Windows.h>
+#endif
+
 //! \defgroup grp_Indenter All concerning handling of the indenter.
 
 /*!
@@ -211,7 +218,7 @@ QMenu* IndentHandler::getIndenterMenu() {
 
 /*!
     \brief Returns the actions of the context menu used for some actions like saving the indenter config file.
-*/
+ */
 QList<QAction*> IndentHandler::getIndenterMenuActions() {
     QList<QAction*> actionList;
     actionList << actionLoad_Indenter_Config_File << actionSave_Indenter_Config_File << actionCreateShellScript << actionResetIndenterParameters;
@@ -346,7 +353,7 @@ QString IndentHandler::callIndenter(QString sourceCode, QString inputFileExtensi
 
     The \a inputFileExtension has to be given as parameter so the called indenter
     can identify the programming language if needed.
-*/
+ */
 QString IndentHandler::callJavaScriptIndenter(QString sourceCode) {
     QScriptEngine engine;
 
@@ -370,7 +377,7 @@ QString IndentHandler::callJavaScriptIndenter(QString sourceCode) {
 
     The \a inputFileExtension has to be given as parameter so the called indenter
     can identify the programming language if needed.
-*/
+ */
 QString IndentHandler::callExecutableIndenter(QString sourceCode, QString inputFileExtension) {
     Q_ASSERT_X( !inputFileName.isEmpty(), "callIndenter", "inputFileName is empty" );
 //    Q_ASSERT_X( !outputFileName.isEmpty(), "callIndenter", "outputFileName is empty" );
@@ -404,9 +411,14 @@ QString IndentHandler::callExecutableIndenter(QString sourceCode, QString inputF
     QFile::remove(tempDirctoryStr + "/" + inputFileName + inputFileExtension);
     QFile inputSrcFile(tempDirctoryStr + "/" + inputFileName + inputFileExtension);
     // Write the source code to the input file for the indenter
-    inputSrcFile.open( QFile::ReadWrite | QFile::Text );
-    inputSrcFile.write( sourceCode.toUtf8() );
-    inputSrcFile.close();
+    if ( inputSrcFile.open( QFile::ReadWrite | QFile::Text ) ) {
+        inputSrcFile.write( sourceCode.toUtf8() );
+        inputSrcFile.close();
+        qDebug() << __LINE__ << " " << __FUNCTION__ << ": Wrote to be indented source code to file " << inputSrcFile.fileName();
+    }
+    else {
+        qCritical() << __LINE__ << " " << __FUNCTION__ << ": Couldn't write to be indented source code to file " << inputSrcFile.fileName();
+    }
 
     // Set the input file for the to be called indenter.
     if ( inputFileParameter.trimmed() == "<" || inputFileParameter == "stdin" ) {
@@ -422,6 +434,49 @@ QString IndentHandler::callExecutableIndenter(QString sourceCode, QString inputF
         parameterOuputFile = " " + outputFileParameter + outputFileName + inputFileExtension;
     }
 
+#ifdef Q_OS_WIN32
+    // Paths may contain Unicode or other foreign characters. Windows commands line tools will
+    // receive als falsely encoded path string by QProcess or they connot correctly handle
+    // the Unicode path on their own.
+    // Because of this the path gets converted to Windows short paths using the 8.3 notation.
+
+    qDebug() << __LINE__ << " " << __FUNCTION__ << ": Temp dir before trying to convert it to short Windows path is" << tempDirctoryStr;
+
+    // At first convert the temp path to Windows like separators.
+    QString tempDirctoryStrHelper = QDir::toNativeSeparators(tempDirctoryStr).replace("\\", "\\\\");
+    // Then convert the QString to a WCHAR array and NULL terminate it.
+    WCHAR *tempDirctoryWindowsStr = new WCHAR[ tempDirctoryStrHelper.length()+1 ];
+    tempDirctoryStrHelper.toWCharArray( tempDirctoryWindowsStr );
+    tempDirctoryWindowsStr[ tempDirctoryStrHelper.length() ] = (WCHAR)NULL;
+
+    // Get the length of the resulting short path.
+    long length = 0;
+    TCHAR *buffer = NULL;
+    length = GetShortPathName((LPCTSTR)tempDirctoryWindowsStr, NULL, 0);
+
+    // If the short path could be retrieved, create a correct sized buffer, store the
+    // short path in it and convert all back to QString.
+    if ( length != 0 ) {
+        buffer = new WCHAR[length];
+        length = GetShortPathName((LPCTSTR)tempDirctoryWindowsStr, buffer, length);
+        tempDirctoryStrHelper = QString::fromWCharArray( buffer );
+        tempDirctoryStr = QDir::fromNativeSeparators(tempDirctoryStrHelper).replace("//", "/");
+        delete buffer;
+        
+        // Check whether the short path still contains some kind of non ascii characters.
+        if ( tempDirctoryStr.length() != tempDirctoryStr.toAscii().length() ) {
+            qWarning() << __LINE__ << " " << __FUNCTION__ << ": Shortened path still contains non ascii characters. Could cause some indenters not to work properly!";
+        }
+    }
+    else {
+        qWarning() << __LINE__ << " " << __FUNCTION__ << ": Couldn't retrieve a short version of the temporary path!";
+    }
+
+    qDebug() << __LINE__ << " " << __FUNCTION__ << ": Temp dir after trying to convert it to short Windows path is " << tempDirctoryStr;
+
+    delete tempDirctoryWindowsStr;
+#endif
+
     // If the config file name is empty it is assumed that all parameters are sent via command line call
     if ( configFilename.isEmpty() ) {
         parameterParameterFile = " " + parameterString;
@@ -461,6 +516,8 @@ QString IndentHandler::callExecutableIndenter(QString sourceCode, QString inputF
     // Set the directory for the indenter execution
     indentProcess.setWorkingDirectory( QFileInfo(tempDirctoryStr).absoluteFilePath() );
 
+    qDebug() << __LINE__ << " " << __FUNCTION__ << ": Will call the indenter in the directory " << indentProcess.workingDirectory() << " using this commandline call: " << indenterCompleteCallString;
+
     indentProcess.start(indenterCompleteCallString);
 
     processReturnString = "";
@@ -497,6 +554,7 @@ QString IndentHandler::callExecutableIndenter(QString sourceCode, QString inputF
                                "(STDOUT):" + encodeToHTML( indentProcess.readAllStandardOutput() ) + "<br>" +
                                "(STDERR):" + encodeToHTML( indentProcess.readAllStandardError() ) + "<br>" +
                                "</pre></html></body>";
+        qWarning() << __LINE__ << " " << __FUNCTION__ << processReturnString;
         QApplication::restoreOverrideCursor();
         errorMessageDialog->showMessage(tr("Error calling Indenter"), processReturnString);
     }
@@ -511,6 +569,7 @@ QString IndentHandler::callExecutableIndenter(QString sourceCode, QString inputF
                               "(STDERR):" + encodeToHTML( indentProcess.readAllStandardError() ) + "<br>" +
                               tr("<br><b>Callstring was:</b> ") + encodeToHTML(indenterCompleteCallString) + 
                               "</html></body>";
+        qWarning() << __LINE__ << " " << __FUNCTION__ << processReturnString;
         QApplication::restoreOverrideCursor();
         errorMessageDialog->showMessage( tr("Indenter returned error"), processReturnString );
     }
@@ -520,15 +579,21 @@ QString IndentHandler::callExecutableIndenter(QString sourceCode, QString inputF
         // If the indenter results are written to stdout, read them from there...
         if ( indentProcess.exitCode() == 0 && outputFileParameter == "stdout"  ) {
             formattedSourceCode = indentProcess.readAllStandardOutput();
+            qDebug() << __LINE__ << " " << __FUNCTION__ << ": Read indenter output from StdOut.";
         }
         // ... else read the output file generated by the indenter call.
         else {
             QFile outSrcFile(tempDirctoryStr + "/" + outputFileName + inputFileExtension);
-            outSrcFile.open(QFile::ReadOnly | QFile::Text);
-            QTextStream outSrcStrm(&outSrcFile);
-            outSrcStrm.setCodec( QTextCodec::codecForName("UTF-8") );
-            formattedSourceCode = outSrcStrm.readAll();
-            outSrcFile.close();
+            if ( outSrcFile.open(QFile::ReadOnly | QFile::Text) ) {
+                QTextStream outSrcStrm(&outSrcFile);
+                outSrcStrm.setCodec( QTextCodec::codecForName("UTF-8") );
+                formattedSourceCode = outSrcStrm.readAll();
+                outSrcFile.close();
+                qDebug() << __LINE__ << " " << __FUNCTION__ << ": Read indenter output from file " << outSrcFile.fileName();
+            }
+            else {
+                qCritical() << __LINE__ << " " << __FUNCTION__ << ": Couldn't read indenter output from file " << outSrcFile.fileName();
+            }
         }
     }
     else {
@@ -1401,8 +1466,8 @@ void IndentHandler::retranslateUi() {
     actionSave_Indenter_Config_File->setShortcut(QApplication::translate("IndentHandler", "Alt+S", 0, QApplication::UnicodeUTF8));
 
     actionCreateShellScript->setText(QApplication::translate("IndentHandler", "Create Indenter Call Shell Script", 0, QApplication::UnicodeUTF8));
-    actionCreateShellScript->setToolTip(QApplication::translate("IndentHandler", "Create a shell script that calls the current selected indenter for formatting an as parameter given file with the current indent settings", 0, QApplication::UnicodeUTF8));
-    actionCreateShellScript->setStatusTip(QApplication::translate("IndentHandler", "Create a shell script that calls the current selected indenter for formatting an as parameter given file with the current indent settings", 0, QApplication::UnicodeUTF8));
+    actionCreateShellScript->setToolTip(QApplication::translate("IndentHandler", "Create a shell script that calls the current selected indenter for formatting an as parameter given file with the current indent settings.", 0, QApplication::UnicodeUTF8));
+    actionCreateShellScript->setStatusTip(QApplication::translate("IndentHandler", "Create a shell script that calls the current selected indenter for formatting an as parameter given file with the current indent settings.", 0, QApplication::UnicodeUTF8));
 
     actionResetIndenterParameters->setText(QApplication::translate("IndentHandler", "Reset indenter parameters", 0, QApplication::UnicodeUTF8));
     actionResetIndenterParameters->setToolTip(QApplication::translate("IndentHandler", "Resets all indenter parameters to the default values.", 0, QApplication::UnicodeUTF8));
@@ -1629,7 +1694,7 @@ QString IndentHandler::encodeToHTML(const QString &text) {
     htmlText.replace("'", "&#39;");
     htmlText.replace("^", "&circ;");
     htmlText.replace("~", "&tilde;");
-    htmlText.replace("", "&euro;");
-    htmlText.replace("", "&copy;");
+    htmlText.replace("€", "&euro;");
+    htmlText.replace("©", "&copy;");
     return htmlText;
 }
