@@ -21,9 +21,11 @@
 #include <QApplication>
 
 #include "UiGuiIndentServer.h"
-
+#include "UiGuiLogger.h"
 #include "UiGuiIniFileParser.h"
 #include "UiGuiSettings.h"
+#include "UiGuiVersion.h"
+#include "UiGuiSystemInfo.h"
 
 /*!
     /brief Entry point to UniversalIndentGUI application.
@@ -38,6 +40,7 @@
 int main(int argc, char *argv[]) {
     QApplication app(argc, argv);
     QString file2OpenOnStart = "";
+    int verboseLevel = 1;
     bool startAsPlugin = false;
     bool startAsServer = false;
 
@@ -68,19 +71,49 @@ int main(int argc, char *argv[]) {
         else if ( currentArg == "-s" || currentArg == "--server" ) {
             startAsServer = true;
         }
+        // Verbose level parameters.
+        if ( currentArg == "-v" || currentArg == "--verbose" ) {
+            // Test whether a parameter follows the verbose parameter.
+            if ( i + 1 >= argc ) {
+                QMessageBox::information( NULL, "Need additional parameter", "The parameter -v / --verbose needs a following parameter defining the verbose level as a number from 0 to 3." );
+                fprintf(stderr, "The parameter -v / --verbose needs a following parameter defining the verbose level as a number from 0 to 3." );
+                exit(1);
+            }
+            // Set the verbose level.
+            else {
+                i++;
+                verboseLevel = atoi( argv[i] );
+            }
+        }
         else {
             QString message = "Invalid parameter found. Allowed parameters are:\n" \
-                              "No parameters starts without server and full gui.\n" \
                               "-f filename --file filename   : Opens the by filename defined file on start.\n" \
-                              "-p --plugin  : Run as plugin. Server will be startet with a simplified gui.\n" \
-                              "-s --server  : Run as server only without gui.\n"
-                              "If -p and -s are set, -p will be used.";
+                              "-p --plugin        : Run as plugin. Server will be startet with a simplified gui.\n" \
+                              "-s --server        : Run as server only without gui.\n" \
+                              "-v level --verbose level : Sets the verbose level for logging application info.\n" \
+                              "                     Level is a number from 0 to 3, where 0 means even\n" \
+                              "                     log debug info (most log info).\n\n" \
+                              "If -p and -s are set, -p will be used.\n" \
+                              "No parameters starts without server and full gui.";
             QMessageBox::information( NULL, "Invalid parameter", message );
             fprintf(stderr, "Invalid parameter found. Allowed parameters are...");
             exit(1);
         }
     }
 
+    // Init and install the logger function.
+    // Setting UTF-8 as default 8-Bit encoding to ensure that qDebug does no false string conversion.
+    QTextCodec::setCodecForCStrings( QTextCodec::codecForName("UTF-8") );
+    QTextCodec::setCodecForLocale( QTextCodec::codecForName("UTF-8") );
+    // Force creation of an UiGuiLogger instance here, to avoid recursion with SettingsPaths init function.
+#ifdef _DEBUG
+    UiGuiLogger::getInstance(0);
+#else
+    UiGuiLogger::getInstance(verboseLevel);
+#endif
+    qInstallMsgHandler( UiGuiLogger::messageHandler );
+    UiGuiLogger::messageHandler( UiGuiInfoMsg, QString("Starting UiGUI Version %1 %2").arg(PROGRAM_VERSION_STRING).arg(PROGRAM_REVISION).toAscii() );
+    UiGuiLogger::messageHandler( UiGuiInfoMsg, QString("Running on %1").arg(UiGuiSystemInfo::getOperatingSystem()).toAscii() );
 
     // Set default values for all by UniversalIndentGUI used settings objects.
     QCoreApplication::setOrganizationName("UniversalIndentGUI");
@@ -118,6 +151,7 @@ int main(int argc, char *argv[]) {
     }
 
     UiGuiSettings::deleteInstance();
+    UiGuiLogger::deleteInstance();
 
     return returnValue;
 }
